@@ -11,6 +11,10 @@
 #include <sys/ioctl.h>
 #include <linux/serial.h>
 
+#ifndef TIOCGDEV
+#define TIOCGDEV      _IOR('T', 0x32, unsigned int)
+#endif
+
 /**
  * @defgroup KDBint Keyboard devices
  * @ingroup libhdDEVint
@@ -21,31 +25,19 @@
 
 #ifdef __sparc__
 
-struct serial_struct {
-  int     type;
-  int     line;
-  unsigned long   port;
-  int     irq;
-  int     flags;
-  int     xmit_fifo_size;
-  int     custom_divisor;
-  int     baud_base;
-  unsigned short  close_delay;
-  char    io_type;
-  char    reserved_char[1];
-  int     hub6;
-  unsigned short  closing_wait; /* time to wait before closing */
-  unsigned short  closing_wait2; /* no longer used... */
-  unsigned char   *iomem_base;
-  unsigned short  iomem_reg_shift;
-  int     reserved[2];
-};
-
 #ifdef DIET
 typedef unsigned int u_int;
 #endif
 
-#include <asm/kbio.h>
+#ifndef KIOCTYPE
+/* Return keyboard type */
+#	define KIOCTYPE    _IOR('k', 9, int)
+#endif
+#ifndef KIOCLAYOUT
+/* Return Keyboard layout */
+#	define KIOCLAYOUT  _IOR('k', 20, int)
+#endif
+
 #include <asm/openpromio.h>
 #endif
 
