@@ -63,7 +63,7 @@ iw_get_ext(int                  skfd,           /* Socket to the kernel */
            struct iwreq *       pwrq)           /* Fixed part of the request */
 {
   /* Set device name */
-  strncpy(pwrq->ifr_name, ifname, IFNAMSIZ);
+  strncpy(pwrq->ifr_name, ifname, IFNAMSIZ - 1);
   /* Do the request */
   return(ioctl(skfd, request, pwrq));
 }
